/**********************************************************************
** Copyright (C) 2002 Trolltech AS.  All rights reserved.
**
** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#include "listdnd.h"
#include <tqwidget.h>
#include <tqpainter.h>

ListDnd::ListDnd( TQScrollView * eventSource, const char * name )
    : TQObject( eventSource, name ),
      dragInside( FALSE ), dragDelete( TRUE ), dropConfirmed( FALSE ), dMode( Both )
{
    src = eventSource;
    src->setAcceptDrops( TRUE );
    src->installEventFilter( this );
    src->viewport()->installEventFilter( this );

    line = new TQWidget( src->viewport(), 0, TQt::WStyle_NoBorder | WStyle_StaysOnTop );
    line->setBackgroundColor( TQt::black );
    line->resize( src->viewport()->width(), 2 );
    line->hide();
}

void ListDnd::setDragMode( int mode )
{
    dMode = mode;
}

int ListDnd::dragMode() const
{
    return dMode;
}

bool ListDnd::eventFilter( TQObject *, TQEvent * event )
{
    switch ( event->type() ) {
    case TQEvent::DragEnter:
	return dragEnterEvent( (TQDragEnterEvent *) event );
    case TQEvent::DragLeave:
	return dragLeaveEvent( (TQDragLeaveEvent *) event );
    case TQEvent::DragMove:
	return dragMoveEvent( (TQDragMoveEvent *) event );
    case TQEvent::Drop:
	return dropEvent( (TQDropEvent *) event );
    case TQEvent::MouseButtonPress:
	return mousePressEvent( (TQMouseEvent *) event );
    case TQEvent::MouseMove:
	return mouseMoveEvent( (TQMouseEvent *) event );
    default:
	break;
    }
    return FALSE;
}


bool ListDnd::dragEnterEvent( TQDragEnterEvent * event )
{
    if ( dMode == None ) {
	return TRUE;
    }

    bool ok = ( ( ( dMode & Both ) == Both ) ||
		( ( dMode & Internal ) && ( event->source() == src ) ) ||
		( ( dMode & External ) && ( event->source() != src ) ) );

    if ( ok && canDecode( event ) ) {
	event->accept();
	dragInside = TRUE;
	if ( !( dMode & NullDrop ) ) {
	    updateLine( event->pos() );
	    line->show();
	}
    }
    return TRUE;
}

bool ListDnd::dragLeaveEvent( TQDragLeaveEvent * )
{
    dragInside = FALSE;
    line->hide();
    return TRUE;
}

bool ListDnd::dragMoveEvent( TQDragMoveEvent * event )
{
    if ( dragInside && dMode && !( dMode & NullDrop ) ) {
	updateLine( event->pos() );
    }
    return TRUE;
}

bool ListDnd::dropEvent( TQDropEvent * )
{
    // do nothing
    return FALSE;
}

bool ListDnd::mousePressEvent( TQMouseEvent * event )
{
    if ( event->button() == Qt::LeftButton )
	mousePressPos = event->pos();
    return FALSE;
}

bool ListDnd::mouseMoveEvent( TQMouseEvent * )
{
    // do nothing
    return FALSE;
}

void ListDnd::updateLine( const TQPoint & )
{
    // do nothing
}

bool ListDnd::canDecode( TQDragEnterEvent * )
{
    // do nothing
    return FALSE;
}
