/* This file is part of the KDE project
   Copyright (C) 2004 Jens Dagerbo <jens.dagerbo@swipnet.se>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/



#include <tqstring.h>
#include <tqvbox.h>

#include <kdebug.h>
#include <kdialogbase.h>
#include <kiconloader.h>

#include <kdevcore.h>


#include "configwidgetproxy.h"


ConfigWidgetProxy::ConfigWidgetProxy( KDevCore * core )
{
	connect( core, TQT_SIGNAL(configWidget(KDialogBase*)), this, TQT_SLOT(slotConfigWidget( KDialogBase*)) );
	connect( core, TQT_SIGNAL(projectConfigWidget(KDialogBase*)), this, TQT_SLOT(slotProjectConfigWidget( KDialogBase*)) );
}

ConfigWidgetProxy::~ConfigWidgetProxy()
{}

void ConfigWidgetProxy::createGlobalConfigPage( TQString const & title, unsigned int pagenumber, TQString const & icon )
{
	_globalTitleMap.insert( pagenumber, tqMakePair( title, icon ) );
}

void ConfigWidgetProxy::createProjectConfigPage( TQString const & title, unsigned int pagenumber, TQString const & icon )
{
	_projectTitleMap.insert( pagenumber, tqMakePair( title, icon ) );
}

void ConfigWidgetProxy::removeConfigPage( int pagenumber )
{
	_globalTitleMap.remove( pagenumber );
	_projectTitleMap.remove( pagenumber );
}

void ConfigWidgetProxy::slotConfigWidget( KDialogBase * dlg )
{
	TitleMap::Iterator it = _globalTitleMap.begin();
	while ( it != _globalTitleMap.end() )
	{
		_pageMap.insert( dlg->addVBoxPage( it.data().first, it.data().first, BarIcon( it.data().second, TDEIcon::SizeMedium ) ), it.key() );
		++it;
	}

	connect( dlg, TQT_SIGNAL(aboutToShowPage(TQWidget*)), this, TQT_SLOT( slotAboutToShowPage(TQWidget*)) );	
	connect( dlg, TQT_SIGNAL(destroyed()), this, TQT_SLOT(slotConfigWidgetDestroyed()) );
}

void ConfigWidgetProxy::slotProjectConfigWidget( KDialogBase * dlg )
{
	TitleMap::Iterator it = _projectTitleMap.begin();
	while ( it != _projectTitleMap.end() )
	{
		_pageMap.insert( dlg->addVBoxPage( it.data().first, it.data().first, BarIcon( it.data().second, TDEIcon::SizeMedium ) ), it.key() );
		++it;
	}
	
	connect( dlg, TQT_SIGNAL(aboutToShowPage(TQWidget*)), this, TQT_SLOT( slotAboutToShowPage(TQWidget*)) );	
	connect( dlg, TQT_SIGNAL(destroyed()), this, TQT_SLOT(slotConfigWidgetDestroyed()) );
}

void ConfigWidgetProxy::slotConfigWidgetDestroyed( )
{
	_pageMap.clear();
}

void ConfigWidgetProxy::slotAboutToShowPage( TQWidget * page )
{
	if ( !page ) return;
	
	PageMap::Iterator it = _pageMap.find( page );
	if ( it != _pageMap.end() )
	{
		emit insertConfigWidget( static_cast<KDialogBase*>(TQT_TQWIDGET(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))), page, it.data() );
		_pageMap.remove( it );
	}
}

#include "configwidgetproxy.moc"
